Role

Enum Role 

pub enum Role {
    Admin,
    Control,
    Member,
}
Defines a role in the system.

Variants



Admin

Defines an admin role with full access to the system.



Control

Defines a control role with no encryption/decryption permissions but the ability to manage resources.



Member

Defines a member role with encryption and decryption permissions but no management capabilities.

Implementations

Source

impl Role

pub fn scope(&self) -> Scope

Returns the Scope associated with the role.

pub fn is_superset_of(&self, other: Role) -> bool

Returns true if this role is a superset of the other role. For example, Admin is a superset of Member, but Member is not a superset of Admin. This is useful when performing checks to prevent privilege escalation.