pub struct RoleSet(/* private fields */);Expand description
Defines a set of Roles that can be used to represent a user’s roles in the system.
It can contain multiple roles, a single role, or an empty set.
Implementations