pub struct Scope(/* private fields */);Expand description
A Scope is set of Permissions with an allocation-free representation and is cheaply copyable.
Implementations
Sourceimpl Scope
impl Scope
Sourcepub const fn with_permissions(permissions: PermissionFlags) -> Self
pub const fn with_permissions(permissions: PermissionFlags) -> Self
Makes a Scope containing all Permissions in permissions.
Sourcepub const fn with_permission(permission: Permission) -> Self
pub const fn with_permission(permission: Permission) -> Self
Makes a Scope containing permission.
Sourcepub fn with_no_permissions() -> Self
pub fn with_no_permissions() -> Self
Makes a Scope without permissions.
Sourcepub fn merge(self, other: Self) -> Self
pub fn merge(self, other: Self) -> Self
Merges self with other returning a new Scope containing the union of the permissions of both scopes.
Sourcepub fn parse(input: &str) -> Self
pub fn parse(input: &str) -> Self
Parses a Scope from input. Always succeeds, even when the string does not contain a syntactically valid
scope but an empty Scope is returned when this occurs.
Sourcepub fn has_permission(&self, permission: Permission) -> bool
pub fn has_permission(&self, permission: Permission) -> bool
Checks if self contains permission.
Sourcepub fn has_all_permissions(&self, other: Self) -> bool
pub fn has_all_permissions(&self, other: Self) -> bool
Checks if self has at least all of the permissions of other.
Sourcepub fn count_permissions(&self) -> u32
pub fn count_permissions(&self) -> u32
Counts the number of permissions in self.
Sourcepub fn permissions(&self) -> impl Iterator<Item = Permission>
pub fn permissions(&self) -> impl Iterator<Item = Permission>
Returns an Iterator over the Permissions in self.