pub enum Azp {
RootProvider,
Provider(Uuid),
AccessKey(Uuid),
}Expand description
The Authorized Party (azp) claim indicates the type of credential that was used to federate the token.
OIDC indicates that the token was federated from an OIDC provider.
If an ID is also provided, this indicates that the token was federated from a specific provider, otherwise it was federated from the root provider.
Examples
| Value | Description |
|---|---|
OIDC | Federated from the root provider. |
| `OIDC | 123e4567-e89b-12d3-a456-426614174000` |
| `CSAK | NWMLYZSTECEIGLDL` |
Variants
RootProvider
Provider(Uuid)
The OIDC provider ID used when federating a 3rd party token.
AccessKey(Uuid)
The Access Key ID used when federating a token from an Access Key.
Implementations
Sourceimpl Azp
impl Azp
Sourcepub fn is_root_provider(&self) -> bool
pub fn is_root_provider(&self) -> bool
Returns true if the azp is the root provider.
Sourcepub fn is_provider(&self) -> bool
pub fn is_provider(&self) -> bool
Returns true if the azp is a provider with a specific ID.
Sourcepub fn is_access_key(&self) -> bool
pub fn is_access_key(&self) -> bool
Returns true if the azp is an access key.